# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import google.protobuf.timestamp_pb2 as timestamp_pb2  # type: ignore
import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.devtools.artifactregistry.v1",
    manifest={
        "GoModule",
    },
)


class GoModule(proto.Message):
    r"""GoModule represents a Go module.

    Attributes:
        name (str):
            The resource name of a Go module.
        version (str):
            The version of the Go module. Must be a valid
            canonical version as defined in
            https://go.dev/ref/mod#glos-canonical-version.
        create_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time when the Go module is
            created.
        update_time (google.protobuf.timestamp_pb2.Timestamp):
            Output only. The time when the Go module is
            updated.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    version: str = proto.Field(
        proto.STRING,
        number=2,
    )
    create_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=3,
        message=timestamp_pb2.Timestamp,
    )
    update_time: timestamp_pb2.Timestamp = proto.Field(
        proto.MESSAGE,
        number=4,
        message=timestamp_pb2.Timestamp,
    )


__all__ = tuple(sorted(__protobuf__.manifest))



# -*- coding: utf-8 -*-
# Copyright 2025 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
from __future__ import annotations

from typing import MutableMapping, MutableSequence

import proto  # type: ignore

__protobuf__ = proto.module(
    package="google.devtools.artifactregistry.v1",
    manifest={
        "KfpArtifact",
    },
)


class KfpArtifact(proto.Message):
    r"""A detailed representation of a KFP artifact.

    Attributes:
        name (str):
            Output only. Resource name of the KFP
            artifact. Since users don't directly interact
            with this resource, the name will be derived
            from the associated version. For example, when
            version = ".../versions/sha256:abcdef...", the
            name will be
            ".../kfpArtifacts/sha256:abcdef...".
        version (str):
            The version associated with the KFP artifact.
            Must follow the Semantic Versioning standard.
    """

    name: str = proto.Field(
        proto.STRING,
        number=1,
    )
    version: str = proto.Field(
        proto.STRING,
        number=2,
    )


__all__ = tuple(sorted(__protobuf__.manifest))
